==> websvn-2.3.3-8-any.pkg.tar.xz: srv/http/websvn/languages/german.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Stephan Stapel, <stephan.stapel@web.de>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// german.php
//
// German language strings

$lang['LANGUAGETAG'] = 'de'; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "German";
$lang["LANGUAGENAMENATIVE"] = "Deutsch";
$lang["LANGUAGENAMEHTML"] = "Deutsch";

$lang["LOG"] = "Log";
$lang["DIFF"] = "Diff";

$lang["NOREP"] = "Kein Repository angegeben.";
$lang["NOPATH"] = "Pfad nicht gefunden";
$lang["NOACCESS"] = "Sie haben keine ausreichende Berechtigungen um diese Inhalte zu lesen";
$lang["RESTRICTED"] = "Beschränkter Zugriff";
$lang["SUPPLYREP"] = "Bitte den Repository-Pfad in include/config.php mit \$config->parentPath oder \$config->addRepository angeben.<p>Genauere Informationen finden sich in der Installationsanleitung";

$lang["DIFFREVS"] = "Vergleich zwischen Revisionen";
$lang["AND"] = "und";
$lang["REV"] = "Revision";
$lang["LINE"] = "Zeile";
$lang["LINENO"] = "Zeilennr.";
$lang["SHOWENTIREFILE"] = "Ganze Datei anzeigen";
$lang["SHOWCOMPACT"] = "Nur geänderte Bereiche";
$lang["IGNOREWHITESPACE"] = "Leerzeichen ignorieren";
$lang["REGARDWHITESPACE"] = "Leerzeichen berücksichtigen";

$lang["LISTING"] = "Verzeichnisansicht";
$lang["FILEDETAIL"] = "Details";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "Vergleich mit vorheriger";
$lang["BLAME"] = "Blame";
$lang["BLAMEFOR"] = "Blame-Information für Rev.";

$lang["REVINFO"] = "Revisionsinformation";
$lang["GOYOUNGEST"] = "Zur aktuellen Revision";
$lang["LASTMOD"] = "Letzte Änderung";
$lang["LOGMSG"] = "Logeintrag";
$lang["CHANGES"] = "Änderungen";
$lang["SHOWCHANGED"] = "Geänderte Dateien anzeigen";
$lang["HIDECHANGED"] = "Geänderte Dateien verstecken";
$lang["NEWFILES"] = "Neue Dateien";
$lang["CHANGEDFILES"] = "Geänderte Dateien";
$lang["DELETEDFILES"] = "Gelöschte Dateien";
$lang["VIEWLOG"] = "Log anzeigen";
$lang["PATH"] = "Pfad";
$lang["AUTHOR"] = "Autor";
$lang["AGE"] = "Alter";
$lang["CURDIR"] = "Aktuelles Verzeichnis";
$lang["TARBALL"] = "Archiv Download";
$lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "Zurück";
$lang["NEXT"] = "Weiter";
$lang["SHOWALL"] = "Alles anzeigen";

$lang["BADCMD"] = "Fehler beim Ausführen des Befehls";
$lang["UNKNOWNREVISION"] = "Revision nicht gefunden";

// $lang["POWERED"] = "Powered by <a href=\"http://www.websvn.info\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion-Projekte";
$lang["SERVER"] = "Subversion-Server";

$lang["FILTER"] = "Filteroptionen";
$lang["STARTLOG"] = "Von Rev.";
$lang["ENDLOG"] = "bis Rev.";
$lang["MAXLOG"] = "Max. Rev.";
$lang["SEARCHLOG"] = "Suche im Log nach";
$lang["CLEARLOG"] = "Aktuelle Suche löschen";
$lang["MORERESULTS"] = "Weitere Ergebnisse finden...";
$lang["NORESULTS"] = "Es wurden keine Treffer erzielt";
$lang["NOMORERESULTS"] = "Keine weiteren Treffer für diese Suche";
$lang['NOPREVREV'] = 'Keine vorherige Revision';

// $lang["RSSFEEDTITLE"] = "WebSVN RSS feed";
$lang["FILESMODIFIED"] = "Veränderte Dateien";
// $lang["RSSFEED"] = "RSS feed";

$lang["DAYLETTER"] = "t";
$lang["HOURLETTER"] = "h";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Los";

$lang["PATHCOMPARISON"] = "Pfadvergleich";
$lang["COMPAREPATHS"] = "Vergleiche Pfade";
$lang["COMPAREREVS"] = "Vergleiche Revisionen";
$lang["PROPCHANGES"] = "Geänderte Eigenschaften:";
$lang["CONVFROM"] = "Dieser Vergleich zeigt die Änderungen zwischen ";
$lang["TO"] = "und";
$lang["REVCOMP"] = "Revisionen vertauschen";
$lang["COMPPATH"] = "Vergleiche Pfad:";
$lang["WITHPATH"] = "Mit Pfad:";
$lang["FILEDELETED"] = "Datei gelöscht";
$lang["FILEADDED"] = "Neue Datei";

==> websvn-2.5-1-any.pkg.tar.xz: srv/http/websvn/languages/german.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Stephan Stapel, <stephan.stapel@web.de>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// german.php
//
// German language strings

$lang['LANGUAGETAG'] = 'de'; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "German";
$lang["LANGUAGENAMENATIVE"] = "Deutsch";
$lang["LANGUAGENAMEHTML"] = "Deutsch";

$lang["LOG"] = "Log";
$lang["DIFF"] = "Diff";

$lang["NOREP"] = "Kein Repository angegeben.";
$lang["NOPATH"] = "Pfad nicht gefunden";
$lang["NOACCESS"] = "Sie haben keine ausreichende Berechtigungen um diese Inhalte zu lesen";
$lang["RESTRICTED"] = "Beschränkter Zugriff";
$lang["SUPPLYREP"] = "Bitte den Repository-Pfad in include/config.php mit \$config->parentPath oder \$config->addRepository angeben.<p>Genauere Informationen finden sich in der Installationsanleitung";

$lang["DIFFREVS"] = "Vergleich zwischen Revisionen";
$lang["AND"] = "und";
$lang["REV"] = "Revision";
$lang["LINE"] = "Zeile";
$lang["LINENO"] = "Zeilennr.";
$lang["SHOWENTIREFILE"] = "Ganze Datei anzeigen";
$lang["SHOWCOMPACT"] = "Nur geänderte Bereiche";
$lang["IGNOREWHITESPACE"] = "Leerzeichen ignorieren";
$lang["REGARDWHITESPACE"] = "Leerzeichen berücksichtigen";

$lang["LISTING"] = "Verzeichnisansicht";
$lang["FILEDETAIL"] = "Details";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "Vergleich mit vorheriger";
$lang["BLAME"] = "Blame";
$lang["BLAMEFOR"] = "Blame-Information für Rev.";

$lang["REVINFO"] = "Revisionsinformation";
$lang["GOYOUNGEST"] = "Zur aktuellen Revision";
$lang["LASTMOD"] = "Letzte Änderung";
$lang["LOGMSG"] = "Logeintrag";
$lang["CHANGES"] = "Änderungen";
$lang["SHOWCHANGED"] = "Geänderte Dateien anzeigen";
$lang["HIDECHANGED"] = "Geänderte Dateien verstecken";
$lang["NEWFILES"] = "Neue Dateien";
$lang["CHANGEDFILES"] = "Geänderte Dateien";
$lang["DELETEDFILES"] = "Gelöschte Dateien";
$lang["VIEWLOG"] = "Log anzeigen";
$lang["PATH"] = "Pfad";
$lang["AUTHOR"] = "Autor";
$lang["AGE"] = "Alter";
$lang["CURDIR"] = "Aktuelles Verzeichnis";
$lang["TARBALL"] = "Archiv Download";
$lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "Zurück";
$lang["NEXT"] = "Weiter";
$lang["SHOWALL"] = "Alles anzeigen";

$lang["BADCMD"] = "Fehler beim Ausführen des Befehls";
$lang["UNKNOWNREVISION"] = "Revision nicht gefunden";

// $lang["POWERED"] = "Powered by <a href=\"https://websvnphp.github.io\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion-Projekte";
$lang["SERVER"] = "Subversion-Server";

$lang["FILTER"] = "Filteroptionen";
$lang["STARTLOG"] = "Von Rev.";
$lang["ENDLOG"] = "bis Rev.";
$lang["MAXLOG"] = "Max. Rev.";
$lang["SEARCHLOG"] = "Suche im Log nach";
$lang["CLEARLOG"] = "Aktuelle Suche löschen";
$lang["MORERESULTS"] = "Weitere Ergebnisse finden...";
$lang["NORESULTS"] = "Es wurden keine Treffer erzielt";
$lang["NOMORERESULTS"] = "Keine weiteren Treffer für diese Suche";
$lang['NOPREVREV'] = 'Keine vorherige Revision';

// $lang["RSSFEEDTITLE"] = "WebSVN RSS feed";
$lang["FILESMODIFIED"] = "Veränderte Dateien";
// $lang["RSSFEED"] = "RSS feed";

$lang["DAYLETTER"] = "t";
$lang["HOURLETTER"] = "h";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Los";

$lang["PATHCOMPARISON"] = "Pfadvergleich";
$lang["COMPAREPATHS"] = "Vergleiche Pfade";
$lang["COMPAREREVS"] = "Vergleiche Revisionen";
$lang["PROPCHANGES"] = "Geänderte Eigenschaften:";
$lang["CONVFROM"] = "Dieser Vergleich zeigt die Änderungen zwischen ";
$lang["TO"] = "und";
$lang["REVCOMP"] = "Revisionen vertauschen";
$lang["COMPPATH"] = "Vergleiche Pfad:";
$lang["WITHPATH"] = "Mit Pfad:";
$lang["FILEDELETED"] = "Datei gelöscht";
$lang["FILEADDED"] = "Neue Datei";
